* Generic session options - page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';                                                     
* Kill default titles on output; TITLE; ODS TRACE OFF;

* Location for original SAS files for these models -- CHANGE THIS TO YOUR FOLDER;
%LET example = C:\Dropbox;
LIBNAME example "&example.";

* Import data from excel;
PROC IMPORT OUT=work.Chapter21 DATAFILE="&example.\Chapter21_Long.xlsx" DBMS=XLSX REPLACE;
     SHEET="Data"; RUN; 

* Open external file to save results to;
ODS RTF FILE="&example./Chapter21_SAS_Models.rtf" STYLE=HTMLBLUE BODYTITLE; RUN;

TITLE "Level-1 Descriptive Statistics for Chapter 27 Example Data";
PROC MEANS NDEC=3 N MEAN STDDEV VAR MIN MAX DATA=work.Chapter21; 
     VAR age time game WPgame dep; RUN; TITLE;
TITLE "Level-2 Descriptive Statistics for Chapter 27 Example Data";
PROC MEANS NDEC=3 N MEAN STDDEV VAR MIN MAX DATA=work.Chapter21; 
     WHERE occasion=1; VAR baseage PMgame; RUN; TITLE;

* Add variable labels;
DATA work.Chapter21; SET work.Chapter21; 
LABEL PersonID=  "PersonID: Level-2 Person Identifier"
      age=       "age: Exact Time-Varying Age"
      occasion=  "occasion: Ordinal Occasion"
      time=      "time: Exact Time Since Baseline"
      roundtime= "roundtime: Exact Time Since Baseline Rounded to Nearest Year"
      baseage=   "baseage: Exact Age at Baseline"
      game=      "game: Hours Daily Gaming Per Occasion"
      PMgame=    "PMgame: Person Mean of Hours Daily Gaming over Occasions"
      dep=       "dep: Depression Per Occasion"
      baseage10= "baseage10: Exact Age at Baseline Centered at 10"
      game3c=    "game3c: Hours Daily Gaming Per Occasion Centered at 3"
      PMgame3c=  "PMgame3c: Person Mean of Hours Daily Gaming over Occasions Centered at 3"
      WPgame=    "WPgame: Hours Daily Gaming Per Occasion Centered at Person Mean";
RUN;

*** Sequential models;

TITLE "Model 1: Empty Means, Random Intercept to Get ICC";
PROC MIXED DATA=work.Chapter21 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 METHOD=ML;
     CLASS PersonID; 
     MODEL dep = / SOLUTION DDFM=RESIDUAL NOTEST;
     RANDOM INTERCEPT / VCORR TYPE=UN SUBJECT=PersonID;
RUN; TITLE;

TITLE "Model 2a: Rounded Saturated Means, Random Intercept to Get Mean Trajectory";
PROC MIXED DATA=work.Chapter21 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 METHOD=ML;
     CLASS PersonID roundtime; 
     MODEL dep = roundtime / NOINT SOLUTION DDFM=RESIDUAL NOTEST;
     RANDOM INTERCEPT / VCORR TYPE=UN SUBJECT=PersonID;
RUN; TITLE;

TITLE "Model 2b: Rounded Saturated Means, Unstructured Variances";
PROC MIXED DATA=work.Chapter21 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 METHOD=ML;
     CLASS PersonID roundtime; 
     MODEL dep = roundtime / NOINT SOLUTION DDFM=RESIDUAL NOTEST;
     REPEATED roundtime / R RCORR TYPE=UN SUBJECT=PersonID;
RUN; TITLE;

TITLE "Model 3: Random Linear Change";
PROC MIXED DATA=work.Chapter21 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 METHOD=ML;
     CLASS PersonID; 
     MODEL dep = time / SOLUTION DDFM=RESIDUAL NOTEST;
     RANDOM INTERCEPT time / GCORR VCORR TYPE=UN SUBJECT=PersonID;
RUN; TITLE;

TITLE "Model 4: Random Linear Change Moderated by Age at Baseline";
PROC MIXED DATA=work.Chapter21 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 METHOD=ML;
     CLASS PersonID; 
     MODEL dep = time baseage10 time*baseage10 / SOLUTION DDFM=RESIDUAL NOTEST;
     RANDOM INTERCEPT time / GCORR TYPE=UN SUBJECT=PersonID;
RUN; TITLE;

TITLE "Model 5: Naive Addition of a Time-Varying Predictor";
PROC MIXED DATA=work.Chapter21 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 METHOD=ML;
     CLASS PersonID; 
     MODEL dep = time baseage10 time*baseage10 game3c / SOLUTION DDFM=RESIDUAL NOTEST;
     RANDOM INTERCEPT time / GCORR VCORR TYPE=UN SUBJECT=PersonID;
RUN; TITLE;

TITLE "Empty Means, Random Intercept to Get ICC for Gaming Predictor";
PROC MIXED DATA=work.Chapter21 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 METHOD=ML;
     CLASS PersonID; 
     MODEL game = / SOLUTION DDFM=RESIDUAL NOTEST;
     RANDOM INTERCEPT / VCORR TYPE=UN SUBJECT=PersonID;
RUN; TITLE;

TITLE "Model 6: Addition of a Person-Mean-Centered Time-Varying Predictor";
PROC MIXED DATA=work.Chapter21 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 METHOD=ML;
     CLASS PersonID; 
     MODEL dep = time baseage10 time*baseage10 WPgame PMgame3c time*PMgame3c / SOLUTION DDFM=RESIDUAL NOTEST;
     RANDOM INTERCEPT time / GCORR VCORR TYPE=UN SUBJECT=PersonID;
RUN; TITLE;

* Close external file of saved results;
ODS RTF CLOSE;
